(function() {
	/**********************************
	 * Compass
	 * 端末の方向に関する情報を取得する
	 **********************************/

	/*
	 * 変数の宣言
	 */
	var compassWatchID;						// コンパス監視停止用のID
	var degreeToRotate01 = "rotate(0deg)";	// コンパスの回転角度
	var degreeToRotate02 = "rotate(0deg)";	// 真北の回転角度

	/*
	 * 現在の方位を取得
	 * コンパスは端末が向いている方向を感知するセンサー
	 * コンパスは方位を0から359.99の範囲で計測する
	 */
	getCurrentHeading = function() {
		applican.compass.getCurrentHeading(currentHeadingSuccess, currentHeadingError);
	};

	/*
	 * 現在の方位を取得成功した時のコールバック
	 */
	currentHeadingSuccess = function(res) {
		getHeadingSuccess(res, "currentHeadingSuccess");
	};

	/*
	 * 現在の方位を取得失敗した時のコールバック
	 */
	currentHeadingError = function(e) {
		var dump = "現在の方位を取得失敗しました\n";
		dump    += "code: " + e.code + "\n";
		document.getElementById("dumpAreaCompass").value = dump;
	};

	/*
	 * コンパス方位を一定の時間間隔で取得
	 * frequency : Number コンパスの向きを取得する間隔(ミリ秒)
	 */
	watchHeading = function() {
		var options = { frequency: 10 };
		compassWatchID = applican.compass.watchHeading(watchHeadingSuccess, watchHeadingError, options);
	};

	/*
	 * コンパス方位を一定の時間間隔で取得成功した時のコールバック
	 */
	watchHeadingSuccess = function(res) {
		getHeadingSuccess(res, "watchHeadingSuccess");
	};

	/*
	 * コンパス方位を一定の時間間隔で取得失敗した時のコールバック
	 */
	watchHeadingError = function(e) {
		var dump = "コンパス方位を取得失敗しました\n";
		dump    += "code: " + e.code + "\n";
		document.getElementById("dumpAreaCompass").value = dump;
	};

	/*
	 * コンパス方位を取得成功した時の共通処理
	 *
	 * res.magneticHeading : Number コンパス方位を磁北を基準に0から359.99の範囲で表す
	 * res.trueHeading     : Number コンパス方位を真北を基準に0から359.99の範囲で表す
	 * res.headingAccuracy : Number 磁北の値と真北の値との角度の差、偏角を表す
	 */
	getHeadingSuccess = function(res) {
		// コンパス方位情報を出力
		var dump = "コンパス方位を取得しました\n";
		dump    += "磁北：" + res.magneticHeading + "\n";
		dump    += "真北：" + res.trueHeading     + "\n";
		dump    += "精度：" + res.headingAccuracy;
		document.getElementById("dumpAreaCompass").value = dump;
		document.getElementById("magneticNum").value = res.trueHeading;

		// コンパス画像を回転
		degreeToRotate01 = "rotate(-" + res.magneticHeading + "deg)";
		document.getElementById("compassPointer").style.MozTransform    = degreeToRotate01;
		document.getElementById("compassPointer").style.WebkitTransform = degreeToRotate01;
		document.getElementById("compassPointer").style.transform       = degreeToRotate01;

		// 真北を回転
		degreeToRotate02 = "rotate(-" + res.trueHeading + "deg)";
		document.getElementById("compassTureNorth").style.MozTransform    = degreeToRotate02;
		document.getElementById("compassTureNorth").style.WebkitTransform = degreeToRotate02;
		document.getElementById("compassTureNorth").style.transform       = degreeToRotate02;
	};

	/*
	 * コンパスの監視を停止
	 */
	clearWatchHeading = function() {
		applican.compass.clearWatch(compassWatchID);
		alert("コンパスの監視を終了しました");
	};

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		//「現在向いている方角を取得」ボタン押下時の処理
		document.getElementById("getHeadingBtn").addEventListener("click", getCurrentHeading, false);
		//「コンパス方位を一定の時間間隔で取得」ボタン押下時の処理
		document.getElementById("watchHeadingBtn").addEventListener("click", watchHeading, false);
		//「コンパスの監視を停止」ボタン押下時の処理
		document.getElementById("clearWatchBtn").addEventListener("click", clearWatchHeading, false);
	}, false);
})();
